==> unify_api-1.1.1%2B1.tar.gz: example_db/lib/ui/home/screen.dart <==
import 'package:after_layout/after_layout.dart';
import 'package:example_db/ui/settings/screen.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';

import '../../data/blocs/bloc.dart';
import '../account/screen.dart';
import '../common/app_drawer.dart';
import '../contacts/common/list.dart';
import '../contacts/screen.dart';
import '../leads/screen.dart';
import '../loans/screen.dart';
import '../video/screen.dart';
import 'common/index.dart';
import 'common/responsive_scaffold.dart';

class HomeScreen extends StatefulWidget {
  const HomeScreen({
    Key key,
    this.scaffoldKey,
  }) : super(key: key);
  final GlobalKey<ScaffoldState> scaffoldKey;

  @override
  _HomeScreenState createState() => _HomeScreenState();
}

class _HomeScreenState extends State<HomeScreen>
    with AfterLayoutMixin<HomeScreen> {
  @override
  void afterFirstLayout(BuildContext context) {
    AuthBloc.refresh(context);
  }

  int _currentIndex = 0;
  @override
  Widget build(BuildContext context) {
    final nav = BlocProvider.of<NavBloc>(context);

    return ResponsiveScaffold(
      scaffoldKey: widget?.scaffoldKey,
      kDesktopBreakpoint: 1500.0,
      title: _buildAppBarTitle(),
      actions: _buildAppBarActions(_currentIndex),
      kTabletBreakpoint: 1200.0,
      drawer: (context, static) => Drawer(
        child: Column(
          children: <Widget>[
            AccountHeader(onRoutePress: (val) {
              if (val == AccountScreen.routeName) {
                if (!static) {
                  Navigator.maybePop(context);
                }
                if (mounted)
                  setState(() {
                    _currentIndex = 6;
                  });
              }
            }),
            Expanded(
              child: SafeArea(
                top: false,
                child: Column(
                  children: <Widget>[
                    Expanded(
                      child: Scrollbar(
                        child: SingleChildScrollView(
                          child: Column(
                            children: <Widget>[
                              _buildMenuItem(
                                context,
                                static,
                                0,
                                title: 'Home',
                                icon: Icons.home,
                              ),
                              _buildMenuItem(
                                context,
                                static,
                                1,
                                title: 'Loans',
                                icon: Icons.folder,
                              ),
                              _buildMenuItem(
                                context,
                                static,
                                2,
                                title: 'Contacts',
                                icon: Icons.contacts,
                              ),
                              _buildMenuItem(
                                context,
                                static,
                                3,
                                title: 'Leads',
                                icon: Icons.people,
                              ),
                              _buildMenuItem(
                                context,
                                static,
                                4,
                                title: 'Marketing',
                                icon: Icons.flag,
                              ),
                              _buildMenuItem(
                                context,
                                static,
                                5,
                                title: 'Unfiy Video',
                                icon: Icons.video_library,
                              ),
                            ],
                          ),
                        ),
                      ),
                    ),
                    _buildMenuItem(
                      context,
                      static,
                      7,
                      title: 'Settings',
                      icon: Icons.settings,
                    ),
                  ],
                ),
              ),
            )
          ],
        ),
      ),
      body: IndexedStack(
        index: _currentIndex,
        children: <Widget>[
          HomeScreenWidget(),
          LoansScreen(),
          ContactsScreen(),
          LeadsScreen(),
          Container(),
          VideosScreen(),
          AccountScreen(),
          SettingsScreen(),
        ],
      ),
    );
  }

  Widget _buildMenuItem(
    BuildContext context,
    bool static,
    int index, {
    @required IconData icon,
    @required String title,
  }) {
    return ListTile(
      selected: _currentIndex == index,
      leading: Icon(icon),
      title: Text(title),
      onTap: () {
        if (!static) {
          Navigator.maybePop(context);
        }
        if (mounted)
          setState(() {
            _currentIndex = index;
          });
      },
    );
  }

  Text _buildAppBarTitle() {
    switch (_currentIndex) {
      case 0:
        return Text('My Unify CRM');
      case 1:
        return Text('Loans');
      case 2:
        return Text('Contacts');
      case 3:
        return Text('Leads');
      case 4:
        return Text('Marketing');
      case 5:
        return Text('Unify Video');
      case 6:
        return Text('My Account');
      case 7:
        return Text('App Settings');
      default:
    }

    return Text('My Unify Mobile');
  }

  List<Widget> _buildAppBarActions(int index) {
    switch (index) {
      case 1:
        return [];
      case 2:
        return [
          IconButton(
            icon: Icon(Icons.refresh),
            onPressed: () => ContactsListScreen.refresh(context),
          )
        ];
      case 3:
        return [];
      case 4:
        return [];
      case 5:
        return [];
      default:
        return [];
    }
  }
}

==> unify_api-1.2.6%2B1.tar.gz: example_db/lib/ui/home/screen.dart <==
import 'package:after_layout/after_layout.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';

import '../../data/blocs/bloc.dart';
import '../account/screen.dart';
import '../common/app_drawer.dart';
import '../contacts/common/list.dart';
import '../contacts/screen.dart';
import '../leads/common/index.dart';
import '../leads/screen.dart';
import '../loans/screen.dart';
import '../marketing/screen.dart';
import '../settings/screen.dart';
import '../video/screen.dart';
import 'common/index.dart';
import 'common/responsive_scaffold.dart';

class HomeScreen extends StatefulWidget {
  const HomeScreen({
    Key key,
    this.scaffoldKey,
  }) : super(key: key);
  final GlobalKey<ScaffoldState> scaffoldKey;

  @override
  _HomeScreenState createState() => _HomeScreenState();
}

class _HomeScreenState extends State<HomeScreen>
    with AfterLayoutMixin<HomeScreen> {
  @override
  void afterFirstLayout(BuildContext context) {
    AuthBloc.refresh(context);
  }

  int _currentIndex = 0;
  @override
  Widget build(BuildContext context) {
    final nav = BlocProvider.of<NavBloc>(context);

    return ResponsiveScaffold(
      scaffoldKey: widget?.scaffoldKey,
      kDesktopBreakpoint: 1500.0,
      title: _buildAppBarTitle(),
      actions: _buildAppBarActions(_currentIndex),
      kTabletBreakpoint: 1200.0,
      drawer: (context, static) => Drawer(
        child: Column(
          children: <Widget>[
            AccountHeader(onRoutePress: (val) {
              if (val == AccountScreen.route) {
                if (!static) {
                  Navigator.maybePop(context);
                }
                if (mounted)
                  setState(() {
                    _currentIndex = 6;
                  });
              }
            }),
            Expanded(
              child: SafeArea(
                top: false,
                child: Column(
                  children: <Widget>[
                    Expanded(
                      child: Scrollbar(
                        child: SingleChildScrollView(
                          child: Column(
                            children: <Widget>[
                              _buildMenuItem(
                                context,
                                static,
                                0,
                                title: 'Home',
                                icon: Icons.home,
                              ),
                              _buildMenuItem(
                                context,
                                static,
                                1,
                                title: 'Loans',
                                icon: Icons.folder,
                              ),
                              _buildMenuItem(
                                context,
                                static,
                                2,
                                title: 'Contacts',
                                icon: Icons.contacts,
                              ),
                              _buildMenuItem(
                                context,
                                static,
                                3,
                                title: 'Leads',
                                icon: Icons.people,
                              ),
                              _buildMenuItem(
                                context,
                                static,
                                4,
                                title: 'Marketing',
                                icon: FontAwesomeIcons.bullseye,
                              ),
                              _buildMenuItem(
                                context,
                                static,
                                5,
                                title: 'Unify Video',
                                icon: Icons.video_library,
                              ),
                            ],
                          ),
                        ),
                      ),
                    ),
                    _buildMenuItem(
                      context,
                      static,
                      7,
                      title: 'Settings',
                      icon: Icons.settings,
                    ),
                  ],
                ),
              ),
            )
          ],
        ),
      ),
      body: IndexedStack(
        index: _currentIndex,
        children: <Widget>[
          HomeScreenWidget(),
          LoansScreen(),
          ContactsScreen(),
          LeadsScreen(),
          MarketingScreen(),
          VideosScreen(),
          AccountScreen(),
          SettingsScreen(),
        ],
      ),
    );
  }

  Widget _buildMenuItem(
    BuildContext context,
    bool static,
    int index, {
    @required IconData icon,
    @required String title,
  }) {
    return ListTile(
      selected: _currentIndex == index,
      leading: Icon(icon),
      title: Text(title),
      onTap: () {
        if (!static) {
          Navigator.maybePop(context);
        }
        if (mounted)
          setState(() {
            _currentIndex = index;
          });
      },
    );
  }

  Text _buildAppBarTitle() {
    switch (_currentIndex) {
      case 0:
        return Text('My Unify CRM');
      case 1:
        return Text('Loans');
      case 2:
        return Text('Contacts');
      case 3:
        return Text('Leads');
      case 4:
        return Text('Marketing');
      case 5:
        return Text('Unify Video');
      case 6:
        return Text('My Account');
      case 7:
        return Text('App Settings');
      default:
    }

    return Text('My Unify Mobile');
  }

  List<Widget> _buildAppBarActions(int index) {
    switch (index) {
      case 0:
        return [
          IconButton(
            icon: Icon(Icons.refresh),
            onPressed: () {
              AuthBloc.refresh(context);
            },
          ),
        ];
      case 1:
        return [
          // IconButton(
          //   icon: Icon(Icons.refresh),
          //   onPressed: () => LoansScreen.refresh(context),
          // )
        ];
      case 2:
        return [
          IconButton(
            icon: Icon(Icons.refresh),
            onPressed: () => ContactsListScreen.refresh(context),
          )
        ];
      case 3:
        return [
          IconButton(
            icon: Icon(Icons.refresh),
            onPressed: () => LeadsListScreen.refresh(context),
          )
        ];
      case 4:
        return [];
      case 5:
        return [];
      default:
        return [];
    }
  }
}
